# frozen_string_literal: true

require 'nokogiri'

module Jekyll
  class Embed
    class Content
      class << self
        # Find URLs on paragraphs.  We do it after rendering because
        # sometimes we use HTML instead of pure Markdown and this way we
        # catch both.
        #
        # @param :content [String]
        # @return [String]
        def embed(content)
          Nokogiri::HTML5.fragment(content).tap do |html|
            html.css('p > a:first-of-type').each do |a|
              next unless a.parent.children.last == a

              url = a['href']
              embed = Jekyll::Embed.embed url

              next if url == embed

              a.parent.replace embed
            end
          end.to_s
        end
      end
    end
  end
end

Jekyll::Hooks.register :posts, :post_convert do |post|
  post.content = Jekyll::Embed::Content.embed post.content
end
